package cn.iocoder.yudao.framework.http.example;

import cn.iocoder.yudao.framework.http.core.Request;
import cn.iocoder.yudao.framework.http.core.Response;
import cn.iocoder.yudao.framework.http.core.client.HttpClient;
import cn.iocoder.yudao.framework.http.core.client.HttpClientFactory;
import lombok.SneakyThrows;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author wuxian
 * @since  2024-10-30
 **/
public class YCloudWhatsappHttp {

    private HttpClient client = null;
    //请求地址
    private static final String WA_URL="https://api.ycloud.com/v2/whatsapp/messages/sendDirectly";

    public YCloudWhatsappHttp() {
        init();
    }

    private void init(){
        client = HttpClientFactory.get(Request.Util.OkHttp);
    }

    @SneakyThrows
    public void postWhatsapp(Map<String, String> header,Map<String,Object> param){
        Request req = Request.create(WA_URL,Request.Method.POST,param);
        req.setParamFormat(Request.ParamFormat.JSON);
        Response res = client.execute(req,Request.Option.create(0,0,header));
        System.out.println("response code ---------------------------->"+res.getCode());
        System.out.println("response content is --------------------》"+res.getBody());
    }
    /**
     *
     * @param code 验证码
     * @param templateName 模板名称
     * @param lanCode 语言编号
     * @return 参数
     */
    private Map<String,Object> setParams(String code,String templateName,String lanCode){
        Map<String, Object> template = new HashMap<>();
        Map<String, String> language = new HashMap<>();
        Components components = new Components();
        Parameters parameters = new Parameters();
        Button button = new Button();
        button.setIndex("0");
        button.setType("button");
        button.setSub_type("url");


        //模板包含语言(language)、组件（components），组件包含参数（parameters）
        parameters.setType("text");
        parameters.setText(code);
        List<Object> list1 = new ArrayList<>();
        list1.add(parameters);

        //构建json中的组件
        components.setType("body");
        components.setParameters(list1);
        button.setParameters(list1);
        List<Object> list2 = new ArrayList<>();
        list2.add(components);
        list2.add(button);

        language.put("code",lanCode);
        language.put("policy","deterministic");

        template.put("language",language);
        template.put("name",templateName);
        template.put("components",list2);

        //构建最终requestBody的json
        Map<String, Object> param = new HashMap<>();
        param.put("from","8618022485824");
        param.put("to","8618102810628");
        param.put("type","template");
        param.put("template",template);
        return param;
    }

    //构建http请求的头
    private Map<String,String>  setHeader(String apiKey){
        Map<String,String> header = new HashMap<>();
        header.put("Accept","application/json");
        header.put("Content-Type", "application/json");
        header.put("X-API-Key", apiKey);
        return header;
    }

    public static void main(String[] args){
        YCloudWhatsappHttp test = new YCloudWhatsappHttp();
        String apiKey = "9dbd912f56c101e53b23cb7b758ffda8";
        String code = "8888";
        String templateName ="ec_verification";
        String lanCode ="en";
        test.postWhatsapp(test.setHeader(apiKey),test.setParams(code,templateName,lanCode));
    }
}

@lombok.Setter
@lombok.Getter
class Parameters{
    private String type;
    private String text;

}

@lombok.Setter
@lombok.Getter
class Components {
    private String type;
    private List<Object> parameters = null;
}

@lombok.Setter
@lombok.Getter
class Button {
        private String type;
        private String sub_type;
        private String index;
        private List<Object> parameters= null;
}



